Lists
=====

Unordered List
--------------

- Markdown
- ReStructured Text
- Textile

Ordered List
------------

1. Python
2. JavaScript
3. HTML5

----

Second Title Slide
==================

----

Code
====

Single Word
-----------

Hello ``World``

Python
------

.. code-block:: python

    def multiply (x, y):
        return x * y

JavaScript
----------

.. code-block:: javascript

    multiply: function (x, y) {
      return x * y;
    }

HTML
----

.. code-block:: html

    <!doctype html>
    <html>
      <head></head>
      <body></body>
    </html>

